# coding: utf-8

"""
    Simple Game Service API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from tangled_game_client.models.get_game_state200_response import GetGameState200Response

class TestGetGameState200Response(unittest.TestCase):
    """GetGameState200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetGameState200Response:
        """Test GetGameState200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetGameState200Response`
        """
        model = GetGameState200Response()
        if include_optional:
            return GetGameState200Response(
                state = tangled_game_client.models.get_game_state_200_response_state.getGameState_200_response_state(
                    num_nodes = 10, 
                    edges = [[0,1,2],[1,2,3],[2,0,0]], 
                    player1_id = 'player1', 
                    player2_id = 'player2', 
                    turn_count = 5, 
                    current_player_index = 0, 
                    player1_node = -1, 
                    player2_node = -1, )
            )
        else:
            return GetGameState200Response(
        )
        """

    def testGetGameState200Response(self):
        """Test GetGameState200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
